#include "DHT.h"

#define DHTPIN 2     // pin du capteur
#define DHTTYPE DHT11   
#define fan4 4 // pin du ventilateur d'humidité
#define fan7 7 // pin du ventilateur de température

int pinPot=0; // pin du potentiomètre

int const MOTEUR = 5 ; // pin du moteur (equivalent à la pompe)

int redPin = 9; // pin de la led rouge
int greenPin = 10; // pin de la led verte
int bluePin = 11; // in de la led bleue

int buzzer=12; // pin du buzzer

int maxHum = 28; // seuil d'humidité (en %)
int maxTemp = 23; // seuil de température (en °c)

int valPot=0; // variable pour récupérer la tension aux bornes du potentiomètre traduite par le CAN . On l’initialise à 0.

int potPin_red = A0; // pin de la résistance variable de la led rouge 
int potPin_green = A1; // pin de la résistance variable de la led verte
int potPin_blue = A2; // pin de la résistance variable de la led bleue

int readValue_red; // variable de stockage de la valeur lue à la résistance variable qui gère la led rouge
int readValue_green; // variable de stockage de la valeur lue à la résistance variable qui gère la led verte
int readValue_blue; // variable de stockage de la valeur lue à la résistance variable qui gère la led bleue

int writeValue_red; // variable d'envoi vers la led rouge
int writeValue_green; // variable d'envoi vers la led verte
int writeValue_blue; // variable d'envoi vers la led bleue

DHT dht(DHTPIN, DHTTYPE);

void setup() {
  
  pinMode(potPin_red, INPUT); // déclare la résisatnce variable de la led rouge comme une entrée
  pinMode(potPin_green, INPUT); // déclare la résisatnce variable de la verte rouge comme une entrée
  pinMode(potPin_blue, INPUT); // déclare la résisatnce variable de la led bleue comme une entrée
  
  pinMode(redPin,OUTPUT); // déclare le pin de la led rouge comme une sortie
  pinMode(bluePin,OUTPUT); // déclare le pin de la led bleue comme une sortie
  pinMode(greenPin, OUTPUT); // déclare le pin de la led verte comme une sortie
  
  pinMode(MOTEUR, OUTPUT);
  
  pinMode(buzzer, OUTPUT);
  
  pinMode(fan4, OUTPUT);
  pinMode(fan7, OUTPUT);
  
  Serial.begin(9600); // initialisation de la communication avec la console

  dht.begin();
}


void loop() {

  delay(2000); // délai avant mesures
  
  float h = dht.readHumidity(); // stockage de la lecture d'humidité
  float t = dht.readTemperature(); // stockage de la lecture de température
  
  valPot=analogRead(A3); //lit la tension, la convertit en valeur numérique et la stocke dans valeurPot

  readValue_red = analogRead(potPin_red); // lit la valeur de la résistance variable pour la led rouge
  readValue_green = analogRead(potPin_green); // lit la valeur de la résistance variable pour la led verte
  readValue_blue = analogRead(potPin_blue); // lit la valeur de la résistance variable pour la led bleue
  
  writeValue_red = (255./1023.)*readValue_red; // calcule la valeur à écrire sur la led rouge
  writeValue_green = (255./1023.)*readValue_green; // calcule la valeur à écrire sur la led verte
  writeValue_blue = (255./1023.)*readValue_blue; // calcule la valeur à écrire sur la led bleue
  
  /* Allumage des leds */
  analogWrite(redPin,writeValue_red); // change l'état de l'éclairage de la led rouge
  analogWrite(greenPin,writeValue_green); // change l'état de l'éclairage de la led verte
  analogWrite(bluePin,writeValue_blue); // change l'état de l'éclairage de la led bleue
  
  /* Message si échec de lecture du capteur */
  if (isnan(h) || isnan(t)) 
  {
    Serial.println("Failed to read from DHT sensor!");
    return;
  }
  
  /* Messages sur le port série */
  Serial.print("Humidity: "); // valeur de l'humidité
  Serial.print(h);
  Serial.print(" %\t");
  Serial.print("Temperature: "); // valeur de la température 
  Serial.print(t);
  Serial.println(" *C ");

  Serial.println(valPot);
  
  /* Détection des niveaux et bas du réservoir */
    if (valPot < 20 || valPot > 1000)
  {
    digitalWrite(buzzer, HIGH);
    delay(1);
    digitalWrite(buzzer, LOW);
    delay(1);     
  }
  
  /* Arrosage plante */
  
     digitalWrite(MOTEUR, HIGH);   // faire tourner le moteur
     delay(5000);                  // attendre 5 secondes
     digitalWrite(MOTEUR, LOW);    // arrêter le moteur
     delay(3000);                  // attendre 3 secondes
     
  /* Activation du ventilateur d'humidité */
  if(h > maxHum) {
      digitalWrite(fan4, HIGH);
  } else {
     digitalWrite(fan4, LOW); 
  }

  /* Activation du ventilateur de température */
  if(t > maxTemp) {
      digitalWrite(fan7, HIGH);
  } else {
     digitalWrite(fan7, LOW); 
  }
  
}
